@@ -8,7 +8,7 @@
 #' @param make_groups Add group variables within which diagnosand values will be calculated. New variables can be created or variables already in the simulations data frame selected. Type name-value pairs within the function \code{vars}, i.e. \code{vars(significant = p.value <= 0.05)}.
 #' @param add_grouping_variables Deprecated. Please use make_groups instead. Variables used to generate groups of simulations for diagnosis. Added to default list: c("design", "estimand_label", "estimator", "outcome", "term")
 #' @param sims The number of simulations, defaulting to 500. sims may also be a vector indicating the number of simulations for each step in a design, as described for \code{\link{simulate_design}}
-#' @param future.seed Option for parallel diagnosis via the function future_lapply. A logical or an integer (of length one or seven), or a list of length(X) with pre-generated random seeds. For details, see ?future_lapply.
+#' @param future.seed Option for parallel diagnosis via the function future_lapply. A logical or an integer (of length one or seven), or a list of length(X) with pre-generated random seeds. By default, this is set to TRUE if the \code{future} and \code{future.apply} packages are installed, and FALSE if not. For details, see ?future_lapply.
 #' @param bootstrap_sims Number of bootstrap replicates for the diagnosands to obtain the standard errors of the diagnosands, defaulting to \code{100}. Set to FALSE to turn off bootstrapping.
 #' @return a list with a data frame of simulations, a data frame of diagnosands, a vector of diagnosand names, and if calculated, a data frame of bootstrap replicates.
 #'
@@ -55,8 +55,8 @@
 #' # to calculate diagnosands, and bootstrap_sims to change how
 #' # many bootstraps are uses to calculate standard errors.
 #' diagnosis <- diagnose_design(design,
-#'                              sims = 500,
-#'                              bootstrap_sims = 150)
+#'                              sims = 100,
+#'                              bootstrap_sims = 100)
 #' tidy(diagnosis)
 #' 
 #' # You may also run diagnose_design in parallel using 
@@ -67,7 +67,7 @@
 #' options(parallelly.fork.enable = TRUE) # required for use in RStudio
 #' plan(multicore) # note other plans are possible, see future
 #' 
-#' diagnose_design(design, sims = 500)
+#' diagnose_design(design)
 #' 
 #' # Select specific diagnosands
 #' reshape_diagnosis(diagnosis, select = "Power")
@@ -85,7 +85,7 @@
 #' get_simulations(diagnosis)
 #' 
 #' # Diagnose using an existing data frame of simulations
-#' simulations <- simulate_design(design, sims = 500)
+#' simulations <- simulate_design(design, sims = 100)
 #' diagnosis   <- diagnose_design(simulations_df = simulations)
 #' diagnosis
 #' 
@@ -220,7 +220,7 @@ diagnose_design <- function(...,
                             diagnosands = NULL,
                             sims = 500,
                             bootstrap_sims = 100,
-                            future.seed = TRUE,
+                            future.seed = requireNamespace("future", quietly = TRUE),
                             make_groups = NULL,
                             add_grouping_variables = NULL) {
   
@@ -231,6 +231,10 @@ diagnose_design <- function(...,
   if(!is.null(add_grouping_variables)){
     warning("The argument add_grouping_variables is deprecated. Please use make_groups instead.", call. = FALSE)
   }
+  
+  if(!(requireNamespace("future", quietly = TRUE) & requireNamespace("future.apply", quietly = TRUE)) && (!is.null(future.seed) & future.seed != FALSE)) {
+    stop("The future or future.apply packages are not installed. The future.seed argument must be set to FALSE.", call. = FALSE)
+  }
 
   # two cases:
   # 1. it's a data frame -- this is the simulations df
