@@ -2,7 +2,7 @@ context("redesign")
 
 test_that("N not changed", {
   N <- 100
-  d <- declare_population(N = N) + NULL
+  d <- declare_model(N = N) + NULL
   expect_equal(N, 100)
 
   expect_length(draw_data(d)$ID, 100)
